pub trait LedgerService:
Send
+ Sync
+ 'static {
// Provided methods
fn get_service_info<'life0, 'async_trait>(
&'life0 self,
request: Request<GetServiceInfoRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetServiceInfoResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn get_object<'life0, 'async_trait>(
&'life0 self,
request: Request<GetObjectRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetObjectResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn batch_get_objects<'life0, 'async_trait>(
&'life0 self,
request: Request<BatchGetObjectsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BatchGetObjectsResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn get_transaction<'life0, 'async_trait>(
&'life0 self,
request: Request<GetTransactionRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetTransactionResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn batch_get_transactions<'life0, 'async_trait>(
&'life0 self,
request: Request<BatchGetTransactionsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BatchGetTransactionsResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn get_checkpoint<'life0, 'async_trait>(
&'life0 self,
request: Request<GetCheckpointRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetCheckpointResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn get_epoch<'life0, 'async_trait>(
&'life0 self,
request: Request<GetEpochRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetEpochResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn list_checkpoints<'life0, 'async_trait>(
&'life0 self,
request: Request<ListCheckpointsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListCheckpointsResponse>>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn list_transactions<'life0, 'async_trait>(
&'life0 self,
request: Request<ListTransactionsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListTransactionsResponse>>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn list_events<'life0, 'async_trait>(
&'life0 self,
request: Request<ListEventsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListEventsResponse>>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
}Expand description
Generated trait containing gRPC methods that should be implemented for use with LedgerServiceServer.
Provided Methods
Sourcefn get_service_info<'life0, 'async_trait>(
&'life0 self,
request: Request<GetServiceInfoRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetServiceInfoResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_service_info<'life0, 'async_trait>(
&'life0 self,
request: Request<GetServiceInfoRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetServiceInfoResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Query the service for general information about its current state.
fn get_object<'life0, 'async_trait>(
&'life0 self,
request: Request<GetObjectRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetObjectResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn batch_get_objects<'life0, 'async_trait>(
&'life0 self,
request: Request<BatchGetObjectsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BatchGetObjectsResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_transaction<'life0, 'async_trait>(
&'life0 self,
request: Request<GetTransactionRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetTransactionResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn batch_get_transactions<'life0, 'async_trait>(
&'life0 self,
request: Request<BatchGetTransactionsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BatchGetTransactionsResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_checkpoint<'life0, 'async_trait>(
&'life0 self,
request: Request<GetCheckpointRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetCheckpointResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_epoch<'life0, 'async_trait>(
&'life0 self,
request: Request<GetEpochRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetEpochResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourcefn list_checkpoints<'life0, 'async_trait>(
&'life0 self,
request: Request<ListCheckpointsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListCheckpointsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_checkpoints<'life0, 'async_trait>(
&'life0 self,
request: Request<ListCheckpointsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListCheckpointsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
List checkpoints matching the provided filters.
Checkpoints are returned in ascending or descending checkpoint sequence number order according to the query options ordering. A checkpoint matches if any transaction it contains satisfies the filter.
Sourcefn list_transactions<'life0, 'async_trait>(
&'life0 self,
request: Request<ListTransactionsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListTransactionsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_transactions<'life0, 'async_trait>(
&'life0 self,
request: Request<ListTransactionsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListTransactionsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
List transactions matching the provided filters.
Transactions are returned in ascending or descending transaction sequence order according to the query options ordering.
Sourcefn list_events<'life0, 'async_trait>(
&'life0 self,
request: Request<ListEventsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListEventsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_events<'life0, 'async_trait>(
&'life0 self,
request: Request<ListEventsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListEventsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
List events matching the provided filters.
Events are returned in ascending or descending packed event sequence order according to the query options ordering.